NAME
Net::DHCPv6::Option::Preference - Preference option (code 7) -- 8-bit server preference value
VERSION
version 0.002
SYNOPSIS
my $pref = Net::DHCPv6::Option::Preference->new(value => 255); # 0-255, higher = more preferred
DESCRIPTION
Implements the Preference option (OPTION_PREFERENCE, code 7) per RFC 8415 21.8. An 8-bit unsigned integer (0-255) where a higher value indicates the server is more preferred by the client.
ALPHA STATUS
ALPHA SOFTWARE. This is an early release. The interface is experimental and subject to change without notice.
METHODS
- new(value => $num)
-
Constructor. Requires an 8-bit value (0-255).
- value
-
Returns the preference value.
SEE ALSO
Net::DHCPv6::Option, Net::DHCPv6::OptionList
AUTHOR
Dean Hamstead <dean@fragfest.com.au>
COPYRIGHT AND LICENSE
This software is Copyright (c) 2026 by Dean Hamstead.
This is free software, licensed under:
The MIT (X11) License